@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2009-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -52,7 +52,7 @@ class Subcommands(click.MultiCommand):
         self._load()
         try:
             return self._commands[name].command
-        except KeyError as error:
+        except KeyError:
             # Returning None here signals click to report usage information
             # and a "No such command" error message.
             return None
