@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2006-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -30,8 +30,8 @@ import logging
 import mailman.config.config
 import mailman.core.logging
 
+from importlib_resources import read_text
 from mailman.interfaces.database import IDatabaseFactory
-from pkg_resources import resource_string as resource_bytes
 from public import public
 from zope.component import getUtility
 from zope.configuration import xmlconfig
@@ -101,8 +101,7 @@ def initialize_1(config_path=None):
     :param config_path: The path to the configuration file.
     :type config_path: string
     """
-    zcml = resource_bytes('mailman.config', 'configure.zcml')
-    xmlconfig.string(zcml.decode('utf-8'))
+    xmlconfig.string(read_text('mailman.config', 'configure.zcml'))
     # By default, set the umask so that only owner and group can read and
     # write our files.  Specifically we must have g+rw and we probably want
     # o-rwx although I think in most cases it doesn't hurt if other can read
