@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -22,11 +22,11 @@ import unittest
 from email import message_from_binary_file
 from email.header import Header
 from email.parser import FeedParser
+from importlib_resources import path
 from mailman.app.lifecycle import create_list
 from mailman.email.message import Message, UserNotification
 from mailman.testing.helpers import get_queue_messages
 from mailman.testing.layers import ConfigLayer
-from pkg_resources import resource_filename
 
 
 class TestMessage(unittest.TestCase):
@@ -100,28 +100,25 @@ Test content
         self.assertEqual(msg.get_payload(), 'Non-ascii text ?.')
 
     def test_as_string_python_bug_27321(self):
-        email_path = resource_filename(
-            'mailman.email.tests.data', 'bad_email.eml')
-        with open(email_path, 'rb') as fp:
-            msg = message_from_binary_file(fp, Message)
-            fp.seek(0)
-            text = fp.read().decode('ascii', 'replace')
-        self.assertEqual(msg.as_string(), text)
+        with path('mailman.email.tests.data', 'bad_email.eml') as email_path:
+            with open(str(email_path), 'rb') as fp:
+                msg = message_from_binary_file(fp, Message)
+                fp.seek(0)
+                text = fp.read().decode('ascii', 'replace')
+            self.assertEqual(msg.as_string(), text)
 
     def test_as_string_python_bug_32330(self):
-        email_path = resource_filename(
-            'mailman.email.tests.data', 'bad_email_2.eml')
-        with open(email_path, 'rb') as fp:
-            msg = message_from_binary_file(fp, Message)
-            fp.seek(0)
-            text = fp.read().decode('ascii', 'replace')
+        with path('mailman.email.tests.data', 'bad_email_2.eml') as email_path:
+            with open(str(email_path), 'rb') as fp:
+                msg = message_from_binary_file(fp, Message)
+                fp.seek(0)
+                text = fp.read().decode('ascii', 'replace')
         self.assertEqual(msg.as_string(), text)
 
     def test_bogus_content_charset(self):
-        email_path = resource_filename(
-            'mailman.email.tests.data', 'bad_email_3.eml')
-        with open(email_path, 'rb') as fp:
-            msg = message_from_binary_file(fp, Message)
-            fp.seek(0)
-            text = fp.read().decode('ascii', 'replace')
+        with path('mailman.email.tests.data', 'bad_email_3.eml') as email_path:
+            with open(str(email_path), 'rb') as fp:
+                msg = message_from_binary_file(fp, Message)
+                fp.seek(0)
+                text = fp.read().decode('ascii', 'replace')
         self.assertEqual(msg.as_string(), text)
