@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -169,6 +169,44 @@ This is a test message.
         self.assertIn('Anne Person <aperson@example.com>',
                       self._msg.as_string())
 
+    def test_decorate_user_name_or_address_as_user_name(self):
+        site_dir = os.path.join(config.TEMPLATE_DIR, 'site', 'en')
+        os.makedirs(site_dir)
+        footer_path = os.path.join(site_dir, 'myfooter.txt')
+        with open(footer_path, 'w', encoding='utf-8') as fp:
+            print('$user_name_or_address', file=fp)
+        getUtility(ITemplateManager).set(
+            'list:member:regular:footer', None, 'mailman:///myfooter.txt')
+        self._mlist.preferred_language = 'en'
+        user = getUtility(IUserManager).make_user(
+            'aperson@example.com', 'Anne Person')
+        member = Member(MemberRole.member, self._mlist.list_id, user)
+        member.preferences = Preferences()
+        member.preferences.preferred_language = 'en'
+        msgdata = dict(member=member)
+        decorate.process(self._mlist, self._msg, msgdata)
+        self.assertIn('Anne Person',
+                      self._msg.as_string())
+
+    def test_decorate_user_name_or_address_as_address(self):
+        site_dir = os.path.join(config.TEMPLATE_DIR, 'site', 'en')
+        os.makedirs(site_dir)
+        footer_path = os.path.join(site_dir, 'myfooter.txt')
+        with open(footer_path, 'w', encoding='utf-8') as fp:
+            print('$user_name_or_address', file=fp)
+        getUtility(ITemplateManager).set(
+            'list:member:regular:footer', None, 'mailman:///myfooter.txt')
+        self._mlist.preferred_language = 'en'
+        user = getUtility(IUserManager).make_user(
+            'aperson@example.com')
+        member = Member(MemberRole.member, self._mlist.list_id, user)
+        member.preferences = Preferences()
+        member.preferences.preferred_language = 'en'
+        msgdata = dict(member=member)
+        decorate.process(self._mlist, self._msg, msgdata)
+        self.assertIn('aperson@example.com',
+                      self._msg.as_string())
+
     def test_decorate_header_footer_with_bad_character_mpa(self):
         site_dir = os.path.join(config.TEMPLATE_DIR, 'site', 'en')
         os.makedirs(site_dir)
