@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -77,11 +77,13 @@ RESOURCE = dict(
     reply_goes_to_list='point_to_list',
     reply_to_address='bee@example.com',
     require_explicit_destination=True,
+    member_roster_visibility='public',
     send_welcome_message=False,
     subject_prefix='[ant]',
     subscription_policy='confirm_then_moderate',
     welcome_message_uri='mailman:///welcome.txt',
     respond_to_post_requests=True,
+    max_num_recipients=150,
     )
 
 
