@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -99,7 +99,7 @@ def list_of_strings_validator(values):
     # bug where an empty string ('') would be interpreted as a valid value ['']
     # to create a singleton list, instead of empty list, which in later stages
     # would create other problems.
-    if values is '':
+    if values is '':  # noqa: F632
         return []
     if not isinstance(values, (list, tuple)):
         values = [values]
