@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -78,21 +78,11 @@ leave
         self._commandq.enqueue(msg, dict(listid='test.example.com',
                                          subaddress='leave'))
         self._runner.run()
-        # Two messages have been sent, both to anne@example.org.  The first
-        # asks for her confirmation of her unsubscription event.  The second
-        # is the results of her email command.
-        items = get_queue_messages('virgin', sort_on='subject',
-                                   expected_count=2)
-        if items[0].msg['from'] == 'test-bounces@example.com':
-            results = items[0].msg
-            confirmation = items[1].msg
-        else:
-            results = items[1].msg
-            confirmation = items[0].msg
+        # One message with confirmation of her unsubscription event should be
+        # sent.
+        items = get_queue_messages('virgin', expected_count=1)
+        confirmation = items[0].msg
         self.assertTrue(str(confirmation['subject']).startswith('confirm'))
-        line = confirmation_line(results)
-        # The confirmation line should name Anne's email address.
-        self.assertIn('anne@example.org', line)
 
     def test_double_leave(self):
         # In this case, the user can be unsubscribed immediately because the
@@ -113,7 +103,4 @@ leave
         self._commandq.enqueue(msg, dict(listid='test.example.com',
                                          subaddress='leave'))
         self._runner.run()
-        items = get_queue_messages('virgin', sort_on='subject',
-                                   expected_count=1)
-        line = confirmation_line(items[0].msg)
-        self.assertEqual(line, 'anne@example.org left test@example.com')
+        get_queue_messages('virgin', sort_on='subject', expected_count=0)
