@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -22,12 +22,13 @@ import shutil
 import tempfile
 import unittest
 
+from contextlib import ExitStack
+from importlib_resources import path as resource_path
 from mailman.app.lifecycle import create_list
 from mailman.config import config
 from mailman.interfaces.languages import ILanguageManager
 from mailman.testing.layers import ConfigLayer
 from mailman.utilities.i18n import TemplateNotFoundError, find, search
-from pkg_resources import resource_filename
 from zope.component import getUtility
 
 
@@ -61,8 +62,11 @@ class TestSearchOrder(unittest.TestCase):
         # $var_dir, except those files that live within Mailman's source
         # tree.  The former will use /v/ as the root and the latter will use
         # /m/ as the root.
-        in_tree = os.path.dirname(resource_filename('mailman', 'templates'))
-        raw_search_order = search(template_file, mailing_list, language)
+        with ExitStack() as resources:
+            in_tree = str(resources.enter_context(
+                resource_path('mailman', 'templates')).parent)
+            raw_search_order = search(
+                resources, template_file, mailing_list, language)
         for path in raw_search_order:
             if path.startswith(self.var_dir):
                 path = '/v' + path[len(self.var_dir):]
@@ -84,24 +88,28 @@ class TestSearchOrder(unittest.TestCase):
         nexteq('/v/templates/lists/l@example.com/it/foo.txt')
         nexteq('/v/templates/domains/example.com/it/foo.txt')
         nexteq('/v/templates/site/it/foo.txt')
+        nexteq('/m/templates/it/foo.txt')
         # 2: Use mlist.preferred_language
         nexteq('/v/templates/lists/l.example.com/de/foo.txt')
         nexteq('/v/templates/lists/l@example.com/de/foo.txt')
         nexteq('/v/templates/domains/example.com/de/foo.txt')
         nexteq('/v/templates/site/de/foo.txt')
+        nexteq('/m/templates/de/foo.txt')
         # 3: Use the site's default language
         nexteq('/v/templates/lists/l.example.com/fr/foo.txt')
         nexteq('/v/templates/lists/l@example.com/fr/foo.txt')
         nexteq('/v/templates/domains/example.com/fr/foo.txt')
         nexteq('/v/templates/site/fr/foo.txt')
+        nexteq('/m/templates/fr/foo.txt')
         # 4: English
         nexteq('/v/templates/lists/l.example.com/en/foo.txt')
         nexteq('/v/templates/lists/l@example.com/en/foo.txt')
         nexteq('/v/templates/domains/example.com/en/foo.txt')
         nexteq('/v/templates/site/en/foo.txt')
+        nexteq('/m/templates/en/foo.txt')
         # 5: After all the site-admin override paths have been searched, the
-        # Mailman in-tree paths are searched.  Note that Mailman only ships
-        # one set of English templates.
+        # Mailman in-tree english path is searched.  Note that Mailman
+        # currently only ships one set of English templates.
         nexteq('/m/templates/en/foo.txt')
 
     def test_no_language_argument_search_order(self):
@@ -114,16 +122,19 @@ class TestSearchOrder(unittest.TestCase):
         nexteq('/v/templates/lists/l@example.com/de/foo.txt')
         nexteq('/v/templates/domains/example.com/de/foo.txt')
         nexteq('/v/templates/site/de/foo.txt')
+        nexteq('/m/templates/de/foo.txt')
         # 2: Use the site's default language
         nexteq('/v/templates/lists/l.example.com/fr/foo.txt')
         nexteq('/v/templates/lists/l@example.com/fr/foo.txt')
         nexteq('/v/templates/domains/example.com/fr/foo.txt')
         nexteq('/v/templates/site/fr/foo.txt')
+        nexteq('/m/templates/fr/foo.txt')
         # 3: English
         nexteq('/v/templates/lists/l.example.com/en/foo.txt')
         nexteq('/v/templates/lists/l@example.com/en/foo.txt')
         nexteq('/v/templates/domains/example.com/en/foo.txt')
         nexteq('/v/templates/site/en/foo.txt')
+        nexteq('/m/templates/en/foo.txt')
         # 4: After all the site-admin override paths have been searched, the
         # Mailman in-tree paths are searched.  Note that Mailman only ships
         # one set of English templates.
@@ -136,10 +147,13 @@ class TestSearchOrder(unittest.TestCase):
             self.assertEqual(next(search_order), path)
         # 1: Use the given language argument
         nexteq('/v/templates/site/it/foo.txt')
+        nexteq('/m/templates/it/foo.txt')
         # 2: Use the site's default language
         nexteq('/v/templates/site/fr/foo.txt')
+        nexteq('/m/templates/fr/foo.txt')
         # 3: English
         nexteq('/v/templates/site/en/foo.txt')
+        nexteq('/m/templates/en/foo.txt')
         # 4: After all the site-admin override paths have been searched, the
         # Mailman in-tree paths are searched.  Note that Mailman only ships
         # one set of English templates.
@@ -152,8 +166,10 @@ class TestSearchOrder(unittest.TestCase):
             self.assertEqual(next(search_order), path)
         # 1: Use the site's default language
         nexteq('/v/templates/site/fr/foo.txt')
+        nexteq('/m/templates/fr/foo.txt')
         # 2: English
         nexteq('/v/templates/site/en/foo.txt')
+        nexteq('/m/templates/en/foo.txt')
         # 3: After all the site-admin override paths have been searched, the
         # Mailman in-tree paths are searched.  Note that Mailman only ships
         # one set of English templates.
